@@ -9,7 +9,7 @@ sub new {
 }
 
 sub mapper { $_[0]->{mapper} }
-sub values { $_[0]->{values} ||= [] }
+sub values { $_[0]->{values} }
 sub handler { $_[0]->mapper->_target }
 
 sub variables {
